@@ -10,7 +10,7 @@ import sys
 
 from contextlib import contextmanager
 
-__version__ = '0.13.3'
+__version__ = '0.13.6'
 
 from IPython import get_ipython
 from IPython.core.debugger import BdbQuit_excepthook
@@ -140,7 +140,7 @@ def get_config():
     filepaths = []
 
     # Low priority goes first in the list
-    for cfg_file in ("setup.cfg", ".ipdb"):
+    for cfg_file in ("setup.cfg", ".ipdb", "pyproject.toml"):
         cwd_filepath = os.path.join(os.getcwd(), cfg_file)
         if os.path.isfile(cwd_filepath):
             filepaths.append(cwd_filepath)
@@ -170,7 +170,17 @@ def get_config():
             # only if they use setup.cfg
             if filepath.endswith('setup.cfg'):
                 with open(filepath) as f:
+                    parser.remove_section("ipdb")
                     read_func(f)
+            # To use on pyproject.toml, put [tool.ipdb] section
+            elif filepath.endswith('pyproject.toml'):
+                import toml
+                toml_file = toml.load(filepath)
+                if "ipdb" in toml_file["tool"]:
+                    if not parser.has_section("ipdb"):
+                        parser.add_section("ipdb")
+                    for key, value in toml_file["tool"]["ipdb"].items():
+                        parser.set("ipdb", key, str(value))
             else:
                 read_func(ConfigFile(filepath))
     return parser
@@ -217,7 +227,7 @@ def launch_ipdb_on_exception():
 
 
 _usage = """\
-usage: python -m ipdb [-c command] ... pyfile [arg] ...
+usage: python -m ipdb [-m] [-c command] ... pyfile [arg] ...
 
 Debug the Python program given by pyfile.
 
@@ -228,6 +238,9 @@ and in the current directory, if they exist.  Commands supplied with
 To let the script run until an exception occurs, use "-c continue".
 To let the script run up to a given line X in the debugged file, use
 "-c 'until X'"
+
+Option -m is available only in Python 3.7 and later.
+
 ipdb version %s.""" % __version__
 
 
@@ -242,29 +255,36 @@ def main():
         class Restart(Exception):
             pass
 
-    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['help', 'command='])
+    if sys.version_info >= (3, 7):
+        opts, args = getopt.getopt(sys.argv[1:], 'mhc:', ['help', 'command='])
+    else:
+        opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['help', 'command='])
 
     commands = []
+    run_as_module = False
     for opt, optarg in opts:
         if opt in ['-h', '--help']:
             print(_usage)
             sys.exit()
         elif opt in ['-c', '--command']:
             commands.append(optarg)
+        elif opt in ['-m']:
+            run_as_module = True
 
     if not args:
         print(_usage)
         sys.exit(2)
 
     mainpyfile = args[0]     # Get script filename
-    if not os.path.exists(mainpyfile):
+    if not run_as_module and not os.path.exists(mainpyfile):
         print('Error:', mainpyfile, 'does not exist')
         sys.exit(1)
 
     sys.argv = args     # Hide "pdb.py" from argument list
 
     # Replace pdb's dir with script's dir in front of module search path.
-    sys.path[0] = os.path.dirname(mainpyfile)
+    if not run_as_module:
+        sys.path[0] = os.path.dirname(mainpyfile)
 
     # Note on saving/restoring sys.argv: it's a good idea when sys.argv was
     # modified by the script being debugged. It's a bad idea when it was
@@ -273,7 +293,10 @@ def main():
     pdb = _init_pdb(commands=commands)
     while 1:
         try:
-            pdb._runscript(mainpyfile)
+            if run_as_module:
+                pdb._runmodule(mainpyfile)
+            else:
+                pdb._runscript(mainpyfile)
             if pdb._user_requested_quit:
                 break
             print("The program finished and will be restarted")
